@@ -1,7 +1,7 @@
 package BioX::Workflow;
 
 use 5.008_005;
-our $VERSION = '1.0';
+our $VERSION = '1.0.1';
 
 use Moose;
 use File::Find::Rule;
@@ -24,7 +24,8 @@ use Storable qw(dclone);
 use MooseX::Types::Path::Tiny qw/Path Paths AbsPath/;
 use List::Uniq ':all';
 
-use Carp::Always;
+#use Carp::Always;
+
 
 extends 'BioX::Wrapper';
 with 'MooseX::Getopt::Usage';
@@ -33,6 +34,7 @@ with 'MooseX::SimpleConfig';
 
 with 'MooseX::Object::Pluggable';
 
+use MooseX::FileAttribute;
 # For pretty man pages!
 $ENV{TERM} = 'xterm-256color';
 
@@ -590,10 +592,11 @@ Path to workflow workflow. This must be a YAML file.
 
 =cut
 
-has 'workflow' => (
+has_file 'workflow' => (
     is       => 'rw',
-    isa      => 'Str',
     required => 1,
+    must_exist => 1,
+    documentation => q{Your configuration workflow file.},
 );
 
 =head3 rule_based
